==> huaweicloudsdkdli-3.1.138-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/upload_python_file_job_resources_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UploadPythonFileJobResourcesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'body': 'UploadResourcesRequestBody'
    }

    attribute_map = {
        'user_id': 'USER-ID',
        'body': 'body'
    }

    def __init__(self, user_id=None, body=None):
        """UploadPythonFileJobResourcesRequest

        The model defined in huaweicloud sdk

        :param user_id: 
        :type user_id: str
        :param body: Body of the UploadPythonFileJobResourcesRequest
        :type body: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        
        

        self._user_id = None
        self._body = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if body is not None:
            self.body = body

    @property
    def user_id(self):
        """Gets the user_id of this UploadPythonFileJobResourcesRequest.

        :return: The user_id of this UploadPythonFileJobResourcesRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UploadPythonFileJobResourcesRequest.

        :param user_id: The user_id of this UploadPythonFileJobResourcesRequest.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def body(self):
        """Gets the body of this UploadPythonFileJobResourcesRequest.

        :return: The body of this UploadPythonFileJobResourcesRequest.
        :rtype: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UploadPythonFileJobResourcesRequest.

        :param body: The body of this UploadPythonFileJobResourcesRequest.
        :type body: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadPythonFileJobResourcesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.143-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/upload_python_file_job_resources_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UploadPythonFileJobResourcesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'body': 'UploadResourcesRequestBody'
    }

    attribute_map = {
        'user_id': 'USER-ID',
        'body': 'body'
    }

    def __init__(self, user_id=None, body=None):
        r"""UploadPythonFileJobResourcesRequest

        The model defined in huaweicloud sdk

        :param user_id: 
        :type user_id: str
        :param body: Body of the UploadPythonFileJobResourcesRequest
        :type body: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        
        

        self._user_id = None
        self._body = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if body is not None:
            self.body = body

    @property
    def user_id(self):
        r"""Gets the user_id of this UploadPythonFileJobResourcesRequest.

        :return: The user_id of this UploadPythonFileJobResourcesRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        r"""Sets the user_id of this UploadPythonFileJobResourcesRequest.

        :param user_id: The user_id of this UploadPythonFileJobResourcesRequest.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def body(self):
        r"""Gets the body of this UploadPythonFileJobResourcesRequest.

        :return: The body of this UploadPythonFileJobResourcesRequest.
        :rtype: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UploadPythonFileJobResourcesRequest.

        :param body: The body of this UploadPythonFileJobResourcesRequest.
        :type body: :class:`huaweicloudsdkdli.v1.UploadResourcesRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadPythonFileJobResourcesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
